complete -c flawz -l url -d 'A URL where NIST CVE 1.1 feeds can be found' -r
complete -c flawz -s f -l feeds -d 'List of feeds that are going to be synced' -r
complete -c flawz -s d -l db -d 'Path to the SQLite database used to store the synced CVE data' -r
complete -c flawz -s q -l query -d 'Start with a search query' -r
complete -c flawz -s t -l theme -d 'Set the theme' -r -f -a "{dracula\t'Dracula',nord\t'Nord',one-dark\t'One Dark',solarized-dark\t'Solarized Dark',gruvbox-light\t'Gruvbox Light'}"
complete -c flawz -s u -l force-update -d 'Always fetch feeds'
complete -c flawz -s o -l offline -d 'Do not fetch feeds'
complete -c flawz -s h -l help -d 'Print help (see more with \'--help\')'
complete -c flawz -s V -l version -d 'Print version'
